Skip to contents

The result is cached for the duration of the current R session.

Usage

get_boc_series_group_info(series_group, refresh = FALSE, quiet = FALSE)

Arguments

series_group

A vector of series group identifiers

refresh

(Optional) Refresh currently cached series if TRUE, default is FALSE

quiet

(Optional) Don't emit messages or warnings if TRUE, default is FALSE

Value

a tibble with series metadata, or NULL if the API could not be reached, or NULL if the API could not be reached

Details

Returns NULL, with a warning, if the Bank of Canada API cannot be reached or refuses the request.

Examples

# \donttest{
get_boc_series_group_info("FX_RATES_ANNUAL")
#> Downloading BOC series group info for FX_RATES_ANNUAL
#> # A tibble: 27 × 7
#>    series    label   description link   group_name group_label group_description
#>    <chr>     <chr>   <chr>       <chr>  <chr>      <chr>       <chr>            
#>  1 FXAAUDCAD AUD/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#>  2 FXABRLCAD BRL/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#>  3 FXACNYCAD CNY/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#>  4 FXAEURCAD EUR/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#>  5 FXAHKDCAD HKD/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#>  6 FXAINRCAD INR/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#>  7 FXAIDRCAD IDR/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#>  8 FXAJPYCAD JPY/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#>  9 FXAMYRCAD MYR/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#> 10 FXAMXNCAD MXN/CAD NA          https… FX_RATES_… Annual exc… The annual avera…
#> # ℹ 17 more rows
# }