Skip to contents

The result is cached for the duration of the current R session.

Usage

get_boc_series_info(series, refresh = FALSE, quiet = FALSE)

Arguments

series

A vector of series identifiers

refresh

(Optional) Refresh currently cached series if TRUE, default is FALSE

quiet

(Optional) Don't emit messages or warnings if TRUE, default is FALSE

Value

a tibble with series metadata, or NULL if the API could not be reached, or NULL if the API could not be reached

Details

Returns NULL, with a warning, if the Bank of Canada API cannot be reached or refuses the request.

Examples

# \donttest{
get_boc_series_info(c("FXUSDCAD", "FXEURCAD"))
#> Downloading BOC series info for FXUSDCAD
#> Downloading BOC series info for FXEURCAD
#> # A tibble: 2 × 3
#>   name     label   description                                                  
#>   <chr>    <chr>   <chr>                                                        
#> 1 FXUSDCAD USD/CAD Daily average exchange rate: daily value of the US dollar ex…
#> 2 FXEURCAD EUR/CAD Daily average exchange rate: daily value of the euro express…
# }