Skip to contents

The list of series is cached for the duration of the current R session.

Usage

list_boc_series(refresh = FALSE, quiet = FALSE)

Arguments

refresh

(Optional) Refresh currently cached series if TRUE, default is FALSE

quiet

(Optional) Don't emit messages or warnings if TRUE, default is FALSE

Value

a tibble with series information, or NULL if the API could not be reached

Details

Returns NULL, with a warning, if the Bank of Canada API cannot be reached or refuses the request.

Examples

# \donttest{
series <- list_boc_series()
#> Downloading BOC series list...
head(series)
#> # A tibble: 6 × 4
#>   name   label                        description                          link 
#>   <chr>  <chr>                        <chr>                                <chr>
#> 1 A.AGRI Annual BCPI Agriculture      Annual Bank of Canada commodity pri… http…
#> 2 A.BCNE Annual BCPI Excluding Energy Annual Bank of Canada commodity pri… http…
#> 3 A.BCPI Annual BCPI Total            Annual Bank of Canada commodity pri… http…
#> 4 A.ENER Annual BCPI Energy           Annual Bank of Canada commodity pri… http…
#> 5 A.FISH Annual BCPI Fish             Annual Bank of Canada commodity pri… http…
#> 6 A.FOPR Annual BCPI Forestry         Annual Bank of Canada commodity pri… http…
# }