Get series to series group link and date of last available data point
Source:R/boc.R
get_boc_all_series_last_date.RdRetrieves the most recent observation for every series group. This makes one request per series group - upwards of 2500 of them - and is cached for the duration of the current R session.
Usage
get_boc_all_series_last_date(
quarter_convention = getOption("canbank.quarter_convention", "middle"),
quiet = TRUE,
refresh = FALSE
)Arguments
- quarter_convention
(Optional) Which day to use for observations the API reports as a quarter rather than a date, see
get_boc_series_group. Defaults togetOption("canbank.quarter_convention", "middle").- quiet
(Optional) Don't emit messages or warnings if
TRUE, default isTRUE- refresh
(Optional) Refresh currently cached data if
TRUE, default isFALSE
Value
a tibble with series, series group and last available date (NA
for series that are not indexed by date), or NULL if the API could
not be reached