The list of series groups is cached for the duration of the current R session.
Details
Returns NULL, with a warning, if the Bank of Canada API cannot be
reached or refuses the request.
Examples
# \donttest{
series_groups <- list_boc_series_groups()
#> Downloading BOC series group list...
head(series_groups)
#> # A tibble: 6 × 4
#> name label description link
#> <chr> <chr> <chr> <chr>
#> 1 A4_FUNDS_CONSUMER Funds advanced and outstanding balances … "Month-end… http…
#> 2 A4_FUNDS_EXTENDED Funds advanced and outstanding balances … "Month-end… http…
#> 3 A4_FUNDS_GRAPH Funds advanced and outstanding balances … "Month-end… http…
#> 4 A4_FUNDS_MONTHLY Funds advanced and outstanding balances … "Month-end… http…
#> 5 A4_FUNDS_MORTGAGES Funds advanced and outstanding balances … "Month-end… http…
#> 6 A4_FUNDS_VARIABLE Funds advanced and outstanding balances … "Month-end… http…
# }